#include <cstddef>
#include <iostream>
#include <limits>
#include <memory>
#include <stdexcept>
#include <string>
#include <type_traits>
#include <utility>

enum class Color {
	None = 0,
	White = 1,
	Black = 2,
};

Color
opposite(Color color) {
	return color == Color::White ? Color::Black : Color::White;
}

class Board {
	static constexpr auto transposition_table_size = 2 << 10;
	static constexpr auto win_score = 10000;

	Color currentColor;
	int height[7];
	Color grid[7][6];

	struct Transposition {
		bool valid;
		int score;
		std::size_t hash;
	};

	std::unique_ptr<Transposition[]> transposition_table;

  public:
	Board() : height{}, grid{{Color::None}}, currentColor{Color::White} { transposition_table = std::make_unique<Transposition[]>(transposition_table_size); }

	int get_best_move() {
		int bestColumn = 0;
		int bestScore = -win_score;

		for (int column = 0; column < 7; ++column) {
			if (height[column] == 6) {
				continue;
			}
			drop(column);
			int score = is_win(opposite(currentColor), column, height[column] - 1) ? win_score : -negamax(6, -win_score, win_score);
			undrop(column);

			if (score > bestScore) {
				bestColumn = column;
				bestScore = score;
			}
		}

		return bestColumn;
	}

	void drop(int column) {
		auto &columnHeight = height[column];
		if (columnHeight >= 6) {
			throw std::runtime_error{"Attempted to drop a tile on a full column"};
		}
		grid[column][columnHeight] = currentColor;
		currentColor = opposite(currentColor);
		++columnHeight;
	}
	void undrop(int column) {
		auto &columnHeight = height[column];
		--columnHeight;
		grid[column][columnHeight] = Color::None;
		currentColor = opposite(currentColor);
	}

	int negamax(int depth, int alpha, int beta) {
		auto const hash = state_hash();
		auto &entry = transposition_table[hash % transposition_table_size];
		if (entry.valid && entry.hash == hash) {
			return entry.score;
		}
		if (depth < 0) {
			return eval();
		}

		for (int column = 0; column < 7; ++column) {
			if (height[column] == 6) {
				continue;
			}
			drop(column);
			int score = is_win(opposite(currentColor), column, height[column] - 1) ? win_score : -negamax(depth - 1, -beta, -alpha);
			undrop(column);
			if (score > beta) {
				return beta;
			}
			if (score > alpha) {
				alpha = score;
			}
		}

		entry.valid = true;
		entry.hash = hash;
		entry.score = alpha;

		return alpha;
	}

	int eval() { return advantage(currentColor) - advantage(opposite(currentColor)); }

	int advantage(Color color) {
		int total = 0;
		for (int column = 0; column < 7; ++column) {
			int count = 0;
			for (int row = height[column] - 1; row >= 0 && grid[column][row] == color; --row) {
				++count;
			}

			total += count;
		}

		return total;
	}

	bool is_win(Color color, int column, int row) {
		std::pair<int, int> deltas[] = {
		    {0, 1}, {0, -1}, {1, 0}, {-1, 0}, {1, 1}, {1, -1}, {-1, 1}, {-1, -1},
		};

		for (auto const &[deltaX, deltaY] : deltas) {
			for (int offset = 0; offset < 4; ++offset) {
				auto const offsetColumn = column + deltaY * offset;
				auto const offsetRow = row + deltaX * offset;
				if (offsetColumn < 0 || offsetColumn >= 7 || offsetRow < 0 || offsetRow >= 6 || grid[offsetColumn][offsetRow] != color) {
					goto next;
				}
			}
			return true;
		next:
			continue;
		}

		return false;
	}

	std::size_t state_hash() {
		std::size_t hash = 0;
		for (int column = 0; column < 7; ++column) {
			for (int row = 5; row >= 0; --row) {
				hash = hash * 3 + static_cast<std::underlying_type_t<Color>>(grid[column][row]);
			}
		}
		return hash;
	}
};

int
main(int argc, char const **argv) {
	char turn;
	std::cin >> turn;

	Board board{};

	try {
		switch (turn) {
			while (true) {
			case 'f': {
				int move = board.get_best_move();
				std::cout << move << std::endl;
				board.drop(move);
				[[fallthrough]];
			}
			case 's': {
				int move;
				std::cin >> move;
				board.drop(move);
			}
			}
		}
	} catch (std::exception const ex) { std::cerr << ex.what() << std::endl; }
}